@@ -46,8 +46,10 @@ import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.ILogAble;
 import org.sat4j.specs.IProblem;
 import org.sat4j.specs.ISolver;
+import org.sat4j.specs.ISolverService;
 import org.sat4j.specs.TimeoutException;
 import org.sat4j.tools.ModelIteratorToSATAdapter;
+import org.sat4j.tools.RupSearchListener;
 import org.sat4j.tools.SearchEnumeratorListener;
 import org.sat4j.tools.SearchMinOneListener;
 
@@ -153,7 +155,7 @@ public abstract class AbstractLauncher implements Serializable, ILogAble {
     }
 
     public void displayLicense() {
-        log("SAT4J: a SATisfiability library for Java (c) 2004-2012 Artois University and CNRS"); //$NON-NLS-1$
+        log("SAT4J: a SATisfiability library for Java (c) 2004-2013 Artois University and CNRS"); //$NON-NLS-1$
         log("This is free software under the dual EPL/GNU LGPL licenses."); //$NON-NLS-1$
         log("See www.sat4j.org for details."); //$NON-NLS-1$
     }
@@ -185,6 +187,16 @@ public abstract class AbstractLauncher implements Serializable, ILogAble {
         }
         log("#constraints  " + aProblem.nConstraints()); //$NON-NLS-1$
         aProblem.printInfos(this.out);
+        if (System.getProperty("UNSATPROOF") != null) {
+            String proofFile = problemname + ".rupproof";
+            this.solver
+                    .setSearchListener(new RupSearchListener<ISolverService>(
+                            proofFile));
+            if (!this.silent) {
+                System.out.println(this.solver.getLogPrefix()
+                        + "Generating unsat proof in file " + proofFile);
+            }
+        }
         return aProblem;
     }
 
