@@ -212,6 +212,18 @@ public final class VecInt implements IVecInt {
             return new IVecInt[0];
         };
 
+        @Override
+        public boolean equals(Object o) {
+            if (o instanceof IVecInt) {
+                return ((IVecInt) o).isEmpty();
+            }
+            return false;
+        }
+
+        @Override
+        public int hashCode() {
+            return 0;
+        }
     };
 
     public VecInt() {
@@ -403,7 +415,6 @@ public final class VecInt implements IVecInt {
 
     public void moveTo2(IVecInt dest) {
         VecInt ndest = (VecInt) dest;
-        int s = ndest.nbelem;
         int tmp[] = ndest.myarray;
         ndest.myarray = this.myarray;
         ndest.nbelem = this.nbelem;
@@ -498,19 +509,19 @@ public final class VecInt implements IVecInt {
     }
 
     void selectionSort(int from, int to) {
-        int i, j, best_i;
+        int i, j, besti;
         int tmp;
 
         for (i = from; i < to - 1; i++) {
-            best_i = i;
+            besti = i;
             for (j = i + 1; j < to; j++) {
-                if (this.myarray[j] < this.myarray[best_i]) {
-                    best_i = j;
+                if (this.myarray[j] < this.myarray[besti]) {
+                    besti = j;
                 }
             }
             tmp = this.myarray[i];
-            this.myarray[i] = this.myarray[best_i];
-            this.myarray[best_i] = tmp;
+            this.myarray[i] = this.myarray[besti];
+            this.myarray[besti] = tmp;
         }
     }
 
@@ -587,13 +598,13 @@ public final class VecInt implements IVecInt {
      */
     @Override
     public boolean equals(Object obj) {
-        if (obj instanceof VecInt) {
-            VecInt v = (VecInt) obj;
-            if (v.nbelem != this.nbelem) {
+        if (obj instanceof IVecInt) {
+            IVecInt v = (IVecInt) obj;
+            if (v.size() != this.nbelem) {
                 return false;
             }
             for (int i = 0; i < this.nbelem; i++) {
-                if (v.myarray[i] != this.myarray[i]) {
+                if (v.get(i) != this.myarray[i]) {
                     return false;
                 }
             }
