@@ -37,10 +37,10 @@ import org.sat4j.minisat.core.DataStructureFactory;
 import org.sat4j.minisat.core.ILits;
 import org.sat4j.minisat.core.Learner;
 import org.sat4j.minisat.core.Propagatable;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.UnitPropagationListener;
 
 /**
  * @author leberre To change the template for this generated type comment go to
