@@ -38,10 +38,10 @@ import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
 import org.sat4j.minisat.core.Propagatable;
 import org.sat4j.minisat.core.Undoable;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVecInt;
 import org.sat4j.specs.IteratorInt;
+import org.sat4j.specs.UnitPropagationListener;
 
 /**
  * @author leberre Contrainte de cardinalit?
@@ -278,6 +278,10 @@ public class AtLeast implements Propagatable, Constr, Undoable, Serializable {
         throw new UnsupportedOperationException();
     }
 
+    public void assertConstraintIfNeeded(UnitPropagationListener s) {
+        throw new UnsupportedOperationException();
+    }
+
     /**
      * Textual representation of the constraint
      * 
