@@ -37,9 +37,9 @@ import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
 import org.sat4j.minisat.core.Propagatable;
 import org.sat4j.minisat.core.Undoable;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.UnitPropagationListener;
 
 public class MinWatchCard implements Propagatable, Constr, Undoable,
         Serializable {
@@ -471,7 +471,7 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
     }
 
     public void register() {
-        throw new UnsupportedOperationException();
+        computeWatches();
     }
 
     public int size() {
@@ -486,6 +486,14 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
         throw new UnsupportedOperationException();
     }
 
+    public void assertConstraintIfNeeded(UnitPropagationListener s) {
+        if (this.watchCumul == this.degree) {
+            for (int i = 0; i < this.watchCumul; i++) {
+                s.enqueue(this.lits[i]);
+            }
+        }
+    }
+
     protected void computeWatches() {
         int indSwap = this.lits.length;
         int tmpInt;
@@ -502,7 +510,7 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
                 this.voc.watch(this.lits[i] ^ 1, this);
             }
         }
-        if (learnt()) {
+        if (this.watchCumul <= this.degree) {
             // chercher tous les litteraux a regarder
             // par ordre de niveau decroissant
             int free = 1;
@@ -624,6 +632,12 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
     }
 
     public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
-        throw new UnsupportedOperationException("Not implemented yet!");
+        int bound = p == ILits.UNDEFINED ? this.watchCumul
+                : this.watchCumul - 1;
+        for (int i = 0; i < bound; i++) {
+            int q = lits[i];
+            assert voc.isFalsified(q);
+            outReason.push(q ^ 1);
+        }
     }
 }
