@@ -37,9 +37,15 @@ import static org.sat4j.core.LiteralsUtils.var;
 import java.io.PrintStream;
 import java.io.PrintWriter;
 import java.lang.reflect.Field;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
 
@@ -58,6 +64,7 @@ import org.sat4j.specs.IteratorInt;
 import org.sat4j.specs.Lbool;
 import org.sat4j.specs.SearchListener;
 import org.sat4j.specs.TimeoutException;
+import org.sat4j.specs.UnitClauseProvider;
 
 /**
  * The backbone of the library providing the modular implementation of a MiniSAT
@@ -158,6 +165,8 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
     private String prefix = "c ";
     private int declaredMaxVarId = 0;
 
+    private UnitClauseProvider unitClauseProvider = UnitClauseProvider.VOID;
+
     protected IVecInt dimacs2internal(IVecInt in) {
         this.__dimacs_out.clear();
         this.__dimacs_out.ensure(in.size());
@@ -1087,9 +1096,11 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
 
     void record(Constr constr) {
         constr.assertConstraint(this);
-        this.slistener.adding(toDimacs(constr.get(0)));
+        int p = toDimacs(constr.get(0));
+        this.slistener.adding(p);
         if (constr.size() == 1) {
             this.stats.learnedliterals++;
+            this.slistener.learnUnit(p);
         } else {
             this.learner.learns(constr);
         }
@@ -1162,48 +1173,37 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
 
         do {
             this.slistener.beginLoop();
-            // propage les clauses unitaires
+            // propagate unit clauses and other constraints
             Constr confl = propagate();
             assert this.trail.size() == this.qhead;
 
             if (confl == null) {
                 // No conflict found
-                // simpliFYDB() prevents a correct use of
-                // constraints removal.
                 if (decisionLevel() == 0 && this.isDBSimplificationAllowed) {
-                    // // Simplify the set of problem clause
-                    // // iff rootLevel==0
                     this.stats.rootSimplifications++;
                     boolean ret = simplifyDB();
                     assert ret;
                 }
-                // was learnts.size() - nAssigns() > nofLearnts
-                // if (nofLearnts.obj >= 0 && learnts.size() > nofLearnts.obj) {
                 assert nAssigns() <= this.voc.realnVars();
                 if (nAssigns() == this.voc.realnVars()) {
                     modelFound();
-                    this.slistener
-                            .solutionFound((this.fullmodel != null) ? this.fullmodel
+                    this.slistener.solutionFound(
+                            (this.fullmodel != null) ? this.fullmodel
                                     : this.model, this);
                     if (this.sharedConflict == null) {
                         cancelUntil(this.rootLevel);
                         return Lbool.TRUE;
                     } else {
-                        // listener called ISolverService.backtrack()
                         confl = this.sharedConflict;
-                        this.sharedConflict = null;
                     }
                 } else {
                     if (this.restarter.shouldRestart()) {
-                        // Reached bound on number of conflicts
-                        // Force a restart
                         cancelUntil(this.rootLevel);
                         return Lbool.UNDEFINED;
                     }
                     if (this.needToReduceDB) {
                         reduceDB();
                         this.needToReduceDB = false;
-                        // Runtime.getRuntime().gc();
                     }
                     if (this.sharedConflict == null) {
                         // New variable decision
@@ -1219,14 +1219,12 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
                             assert ret;
                         }
                     } else {
-                        // listener called ISolverService.backtrack()
                         confl = this.sharedConflict;
-                        this.sharedConflict = null;
                     }
                 }
             }
             if (confl != null) {
-                // un conflit apparait
+                // conflict found
                 this.stats.conflicts++;
                 this.slistener.conflictFound(confl, decisionLevel(),
                         this.trail.size());
@@ -1256,6 +1254,10 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
                 if (backjumpLevel == this.rootLevel) {
                     this.restarter.onBackjumpToRootLevel();
                 }
+                if (confl == this.sharedConflict) {
+                    this.sharedConflict.assertConstraintIfNeeded(this);
+                    this.sharedConflict = null;
+                }
                 assert decisionLevel() >= this.rootLevel
                         && decisionLevel() >= this.analysisResult.backtrackLevel;
                 if (this.analysisResult.reason == null) {
@@ -1382,8 +1384,10 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         if (this.learnedLiterals.size() > 0) {
             this.qhead = trail.size();
         }
-        System.out.printf("%s implied: %d, decision: %d %n", getLogPrefix(),
-                implied.size(), decisions.size());
+        if (isVerbose()) {
+            System.out.printf("%s implied: %d, decision: %d %n",
+                    getLogPrefix(), implied.size(), decisions.size());
+        }
         this.prime = new int[realNumberOfVariables() + 1];
         int p, d;
         for (int i = 0; i < this.prime.length; i++) {
@@ -2008,6 +2012,9 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         // Solve
         while (status == Lbool.UNDEFINED && this.undertimeout
                 && this.lastConflictMeansUnsat) {
+            int before = this.trail.size();
+            unitClauseProvider.provideUnitClauses(this);
+            this.stats.importedUnits += this.trail.size() - before;
             status = search(assumps);
             if (status == Lbool.UNDEFINED) {
                 this.restarter.onRestart();
@@ -2537,9 +2544,20 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         this.keepHot = keepHot;
     }
 
+    private final Comparator<Integer> dimacsLevel = new Comparator<Integer>() {
+        public int compare(Integer i1, Integer i2) {
+            return voc.getLevel(Math.abs(i2)) - voc.getLevel(Math.abs(i1));
+        }
+    };
+
     public IConstr addClauseOnTheFly(int[] literals) {
+        List<Integer> lliterals = new ArrayList<Integer>();
+        for (Integer d : literals) {
+            lliterals.add(d);
+        }
+        Collections.sort(lliterals, dimacsLevel);
         IVecInt clause = new VecInt(literals.length);
-        for (int d : literals) {
+        for (int d : lliterals) {
             clause.push(LiteralsUtils.toInternal(d));
         }
         this.sharedConflict = this.dsfactory.createUnregisteredClause(clause);
@@ -2547,7 +2565,8 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         addConstr(this.sharedConflict);
         IVecInt reason = new VecInt();
         this.sharedConflict.calcReasonOnTheFly(ILits.UNDEFINED, trail, reason);
-        while (!trail.isEmpty() && !reason.contains(trail.last())) {
+        Set<Integer> subset = fromLastDecisionLevel(reason);
+        while (!trail.isEmpty() && !subset.contains(trail.last())) {
             undoOne();
             if (!trailLim.isEmpty() && trailLim.last() == trail.size()) {
                 trailLim.pop();
@@ -2580,7 +2599,8 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         // for falsifying that constraint
         IVecInt reason = new VecInt();
         this.sharedConflict.calcReasonOnTheFly(ILits.UNDEFINED, trail, reason);
-        while (!trail.isEmpty() && !reason.contains(trail.last())) {
+        Set<Integer> subset = fromLastDecisionLevel(reason);
+        while (!trail.isEmpty() && !subset.contains(trail.last())) {
             undoOne();
             if (!trailLim.isEmpty() && trailLim.last() == trail.size()) {
                 trailLim.pop();
@@ -2588,4 +2608,25 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         }
         return this.sharedConflict;
     }
+
+    protected Set<Integer> fromLastDecisionLevel(IVecInt lits) {
+        Set<Integer> subset = new HashSet<Integer>();
+        int max = -1, q, level;
+        for (int i = 0; i < lits.size(); i++) {
+            q = lits.get(i);
+            level = voc.getLevel(q);
+            if (level > max) {
+                subset.clear();
+                subset.add(q);
+                max = level;
+            } else if (level == max) {
+                subset.add(q);
+            }
+        }
+        return subset;
+    }
+
+    public void setUnitClauseProvider(UnitClauseProvider ucp) {
+        this.unitClauseProvider = ucp;
+    }
 }
