@@ -123,7 +123,7 @@ public final class MaxSatDecorator extends AbstractSelectorVariablesDecorator {
         try {
             this.prevConstr = super.addAtMost(this.lits, this.counter - 1);
         } catch (ContradictionException ce) {
-            this.isSolutionOptimal = true;
+            setSolutionOptimal(true);
             throw ce;
         }
     }
@@ -133,11 +133,9 @@ public final class MaxSatDecorator extends AbstractSelectorVariablesDecorator {
             throws TimeoutException {
 
         boolean result = super.admitABetterSolution(assumps);
-        if (!result) {
-            if (this.prevConstr != null) {
-                super.removeConstr(this.prevConstr);
-                this.prevConstr = null;
-            }
+        if (!result && this.prevConstr != null) {
+            super.removeConstr(this.prevConstr);
+            this.prevConstr = null;
         }
         return result;
     }
@@ -156,7 +154,7 @@ public final class MaxSatDecorator extends AbstractSelectorVariablesDecorator {
     @Override
     void calculateObjectiveValue() {
         this.counter = 0;
-        for (int q : this.prevfullmodel) {
+        for (int q : getPrevfullmodel()) {
             if (q > nVars()) {
                 this.counter++;
             }
@@ -171,4 +169,8 @@ public final class MaxSatDecorator extends AbstractSelectorVariablesDecorator {
         super.addAtMost(this.lits, forcedValue.intValue());
     }
 
+    public void setTimeoutForFindingBetterSolution(int seconds) {
+        // TODO
+        throw new UnsupportedOperationException("No implemented yet");
+    }
 }
