@@ -32,8 +32,7 @@ package org.sat4j.reader;
 import java.io.IOException;
 
 import org.sat4j.specs.ContradictionException;
-import org.sat4j.specs.ISolver;
-import org.sat4j.tools.xplain.HighLevelXplain;
+import org.sat4j.specs.IGroupSolver;
 
 public class GroupedCNFReader extends DimacsReader {
 
@@ -44,13 +43,13 @@ public class GroupedCNFReader extends DimacsReader {
 
     private int numberOfComponents;
 
-    private final HighLevelXplain<ISolver> hlxplain;
+    private final IGroupSolver groupSolver;
 
     private int currentComponentIndex;
 
-    public GroupedCNFReader(HighLevelXplain<ISolver> solver) {
+    public GroupedCNFReader(IGroupSolver solver) {
         super(solver, "gcnf");
-        this.hlxplain = solver;
+        this.groupSolver = solver;
     }
 
     /**
@@ -66,11 +65,7 @@ public class GroupedCNFReader extends DimacsReader {
     protected void readProblemLine() throws IOException, ParseFormatException {
 
         String line = this.scanner.nextLine();
-
-        if (line == null) {
-            throw new ParseFormatException("premature end of file: <p "
-                    + this.formatString + " ...> expected");
-        }
+        assert line != null;
         line = line.trim();
         String[] tokens = line.split("\\s+");
         if (tokens.length < 5 || !"p".equals(tokens[0])
@@ -136,9 +131,9 @@ public class GroupedCNFReader extends DimacsReader {
     protected void flushConstraint() throws ContradictionException {
         try {
             if (this.currentComponentIndex == 0) {
-                this.hlxplain.addClause(this.literals);
+                this.groupSolver.addClause(this.literals);
             } else {
-                this.hlxplain.addClause(this.literals,
+                this.groupSolver.addClause(this.literals,
                         this.currentComponentIndex);
             }
         } catch (IllegalArgumentException ex) {
