@@ -29,10 +29,8 @@
  *******************************************************************************/
 package org.sat4j.reader;
 
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.PrintWriter;
-import java.net.URL;
 import java.util.Locale;
 
 import org.sat4j.specs.ContradictionException;
@@ -96,51 +94,45 @@ public class InstanceReader extends Reader {
 
     @Override
     public IProblem parseInstance(String filename)
-            throws FileNotFoundException, ParseFormatException, IOException,
+            throws ParseFormatException, IOException,
             ContradictionException {
         String fname;
-        boolean isHttp = false;
-        String tempFileName = "";
         String prefix = "";
 
         if (filename.startsWith("http://")) {
-            isHttp = true;
-            tempFileName = filename;
             filename = filename.substring(filename.lastIndexOf('/'),
                     filename.length() - 1);
         }
 
         if (filename.indexOf(':') != -1) {
-
             String[] parts = filename.split(":");
             filename = parts[1];
             prefix = parts[0].toUpperCase(Locale.getDefault());
 
         }
 
-        if (filename.endsWith(".gz")) {
+        if (filename.endsWith(".gz") || filename.endsWith(".bz2")) {
             fname = filename.substring(0, filename.lastIndexOf('.'));
         } else {
             fname = filename;
         }
-        if ("EZCNF".equals(prefix)) {
-            this.reader = getEZSATReader();
-        } else if (fname.endsWith(".aag")) {
-            this.reader = getAAGReader();
-        } else if (fname.endsWith(".aig")) {
-            this.reader = getAIGReader();
-
-        } else {
-            this.reader = getDefaultSATReader();
-        }
-
-        if (isHttp) {
-            return this.reader
-                    .parseInstance(new URL(tempFileName).openStream());
-        }
+        this.reader = handleFileName(fname, prefix);
         return this.reader.parseInstance(filename);
     }
 
+    protected Reader handleFileName(String fname, String prefix) {
+        if ("EZCNF".equals(prefix)) {
+            return getEZSATReader();
+        }
+        if (fname.endsWith(".aag")) {
+            return getAAGReader();
+        }
+        if (fname.endsWith(".aig")) {
+            return getAIGReader();
+        }
+        return getDefaultSATReader();
+    }
+
     @Override
     @Deprecated
     public String decode(int[] model) {
