@@ -57,7 +57,7 @@ public class LecteurDimacs extends Reader implements Serializable {
     private static final long serialVersionUID = 1L;
 
     /* taille du buffer */
-    private final static int TAILLE_BUF = 16384;
+    private static final int TAILLE_BUF = 16384;
 
     private final ISolver s;
 
