@@ -48,14 +48,15 @@ public class LexicoDecorator<T extends ISolver> extends SolverDecorator<T>
 
     protected int currentCriterion = 0;
 
-    private IConstr prevConstr;
+    protected IConstr prevConstr;
 
     private Number currentValue = -1;
 
     protected int[] prevfullmodel;
+    protected int[] prevmodelwithinternalvars;
     protected boolean[] prevboolmodel;
 
-    private boolean isSolutionOptimal;
+    protected boolean isSolutionOptimal;
 
     /**
 	 * 
@@ -85,13 +86,15 @@ public class LexicoDecorator<T extends ISolver> extends SolverDecorator<T>
                 this.prevboolmodel[i] = decorated().model(i + 1);
             }
             this.prevfullmodel = decorated().model();
+            this.prevmodelwithinternalvars = decorated()
+                    .modelWithInternalVariables();
             calculateObjective();
             return true;
         }
         return manageUnsatCase();
     }
 
-    private boolean manageUnsatCase() {
+    protected boolean manageUnsatCase() {
         if (this.prevfullmodel == null) {
             // the problem is UNSAT
             return false;
@@ -148,6 +151,11 @@ public class LexicoDecorator<T extends ISolver> extends SolverDecorator<T>
         return this.prevboolmodel[var - 1];
     }
 
+    @Override
+    public int[] modelWithInternalVariables() {
+        return this.prevmodelwithinternalvars;
+    }
+
     public boolean hasNoObjectiveFunction() {
         return false;
     }
