@@ -44,6 +44,10 @@ import org.sat4j.specs.IVecInt;
  */
 public class Policy extends EncodingStrategyAdapter {
 
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
     private final Sequential seq = new Sequential();
     private final Binary binary = new Binary();
     private final Product product = new Product();
@@ -51,12 +55,12 @@ public class Policy extends EncodingStrategyAdapter {
     private final Binomial binomial = new Binomial();
     private final Ladder ladder = new Ladder();
 
-    private EncodingStrategyAdapter atMostOneEncoding;
-    private EncodingStrategyAdapter atMostKEncoding;
-    private EncodingStrategyAdapter exactlyOneEncoding;
-    private EncodingStrategyAdapter exactlyKEncoding;
-    private EncodingStrategyAdapter atLeastOneEncoding;
-    private EncodingStrategyAdapter atLeastKEncoding;
+    private EncodingStrategyAdapter atMostOneEncoding = null;
+    private EncodingStrategyAdapter atMostKEncoding = null;
+    private EncodingStrategyAdapter exactlyOneEncoding = null;
+    private EncodingStrategyAdapter exactlyKEncoding = null;
+    private EncodingStrategyAdapter atLeastOneEncoding = null;
+    private EncodingStrategyAdapter atLeastKEncoding = null;
 
     private EncodingStrategyAdapter getAdapterFromEncodingName(
             EncodingStrategy encodingName) {
@@ -73,11 +77,32 @@ public class Policy extends EncodingStrategyAdapter {
             return this.product;
         case SEQUENTIAL:
             return this.seq;
+        case NATIVE:
         default:
             return null;
         }
     }
 
+    private EncodingStrategy getEncodingTypeFromAdapter(
+            EncodingStrategyAdapter adapter) {
+        if (adapter instanceof Binary) {
+            return EncodingStrategy.BINARY;
+        } else if (adapter instanceof Binomial) {
+            return EncodingStrategy.BINOMIAL;
+        } else if (adapter instanceof Commander) {
+            return EncodingStrategy.COMMANDER;
+        } else if (adapter instanceof Ladder) {
+            return EncodingStrategy.LADDER;
+        } else if (adapter instanceof Product) {
+            return EncodingStrategy.PRODUCT;
+        } else if (adapter instanceof Sequential) {
+            return EncodingStrategy.SEQUENTIAL;
+        } else {
+            return EncodingStrategy.NATIVE;
+        }
+
+    }
+
     public EncodingStrategyAdapter getAtMostOneEncoding() {
         return this.atMostOneEncoding;
     }
@@ -206,4 +231,19 @@ public class Policy extends EncodingStrategyAdapter {
 
     }
 
+    @Override
+    public String toString() {
+        String s = "";
+        s += "Policy = [At most K: "
+                + getEncodingTypeFromAdapter(getAtMostKEncoding())
+                + ", at most 1: "
+                + getEncodingTypeFromAdapter(getAtMostOneEncoding())
+                + ", exactly K: "
+                + getEncodingTypeFromAdapter(getExactlyKEncoding())
+                + ", exactly 1: "
+                + getEncodingTypeFromAdapter(getExactlyOneEncoding()) + "]";
+
+        return s;
+    }
+
 }
