@@ -1,10 +1,10 @@
 /*******************************************************************************
- * SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
+ * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ *  http://www.eclipse.org/legal/epl-v10.html
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU Lesser General Public License Version 2.1 or later (the
@@ -15,15 +15,17 @@
  * the provisions above and replace them with the notice and other provisions
  * required by the LGPL. If you do not delete the provisions above, a recipient
  * may use your version of this file under the terms of the EPL or the LGPL.
- * 
+ *
  * Based on the original MiniSat specification from:
- * 
+ *
  * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
  * Sixth International Conference on Theory and Applications of Satisfiability
  * Testing, LNCS 2919, pp 502-518, 2003.
  *
  * See www.minisat.se for the original solver in C++.
- * 
+ *
+ * Contributors:
+ *   CRIL - initial API and implementation
  *******************************************************************************/
 
 package org.sat4j.minisat;
@@ -47,58 +49,58 @@ import org.sat4j.specs.TimeoutException;
  *         Preferences - Java - Code Generation - Code and Comments
  */
 public abstract class AbstractAcceptanceTestCase<T extends ISolver> extends
-		TestCase {
+        TestCase {
 
-	/**
+    /**
      * 
      */
-	public AbstractAcceptanceTestCase() {
-		super();
-	}
+    public AbstractAcceptanceTestCase() {
+        super();
+    }
 
-	/**
-	 * @param arg0
-	 */
-	public AbstractAcceptanceTestCase(String arg0) {
-		super(arg0);
-	}
+    /**
+     * @param arg0
+     */
+    public AbstractAcceptanceTestCase(String arg0) {
+        super(arg0);
+    }
 
-	protected T solver;
+    protected T solver;
 
-	protected Reader reader;
+    protected Reader reader;
 
-	protected abstract T createSolver();
+    protected abstract T createSolver();
 
-	/**
-	 * @see TestCase#setUp()
-	 */
-	@Override
-	protected void setUp() {
-		solver = createSolver();
-		reader = createInstanceReader(solver);
-	}
+    /**
+     * @see TestCase#setUp()
+     */
+    @Override
+    protected void setUp() {
+        this.solver = createSolver();
+        this.reader = createInstanceReader(this.solver);
+    }
 
-	protected Reader createInstanceReader(T aSolver) {
-		return new InstanceReader(aSolver);
-	}
+    protected Reader createInstanceReader(T aSolver) {
+        return new InstanceReader(aSolver);
+    }
 
-	@Override
-	protected void tearDown() {
-		solver.reset();
-	}
+    @Override
+    protected void tearDown() {
+        this.solver.reset();
+    }
 
-	protected boolean solveInstance(String filename)
-			throws FileNotFoundException, ParseFormatException, IOException {
-		try {
-			reader.parseInstance(filename);
-			solver.setTimeout(180); // set timeout to 3 minutes.
-			return solver.isSatisfiable();
-		} catch (ContradictionException ce) {
-			return false;
-		} catch (TimeoutException ce) {
-			fail("Timeout: need more time to complete!");
-			return false;
-		}
-	}
+    protected boolean solveInstance(String filename)
+            throws FileNotFoundException, ParseFormatException, IOException {
+        try {
+            this.reader.parseInstance(filename);
+            this.solver.setTimeout(300); // set timeout to 5 minutes.
+            return this.solver.isSatisfiable();
+        } catch (ContradictionException ce) {
+            return false;
+        } catch (TimeoutException ce) {
+            fail("Timeout: need more time to complete!");
+            return false;
+        }
+    }
 
 }
