@@ -162,7 +162,7 @@ public class MinCostDecorator extends PBSolverDecorator implements
 
     public Number calculateObjective() {
         this.objectivevalue = calculateDegree(this.prevmodel);
-        return new Integer(this.objectivevalue);
+        return this.objectivevalue;
     }
 
     private int calculateDegree(int[] prevmodel2) {
@@ -217,4 +217,9 @@ public class MinCostDecorator extends PBSolverDecorator implements
     public boolean isOptimal() {
         return this.isSolutionOptimal;
     }
+
+    public void setTimeoutForFindingBetterSolution(int seconds) {
+        // TODO
+        throw new UnsupportedOperationException("No implemented yet");
+    }
 }
