@@ -42,6 +42,8 @@ import org.sat4j.pb.IPBSolver;
 public class SolverFactory extends ASolverFactory<IPBSolver> {
 
     private static final long serialVersionUID = 1L;
+    
+    private static SolverFactory instance;
 
     /**
      * Builds a SAT solver for the MAX sat evaluation. Full clause learning, no
@@ -58,6 +60,33 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         learning.setVarActivityListener(solver);
         return solver;
     }
+    
+    /**
+     * Private contructor. Use singleton method instance() instead.
+     * 
+     * @see #instance()
+     */
+    private SolverFactory() {
+
+    }
+    
+    private static synchronized void createInstance() {
+        if (instance == null) {
+            instance = new SolverFactory();
+        }
+    }
+
+    /**
+     * Access to the single instance of the factory.
+     * 
+     * @return the singleton of that class.
+     */
+    public static SolverFactory instance() {
+        if (instance == null) {
+            createInstance();
+        }
+        return instance;
+    }
 
     @Override
     public IPBSolver defaultSolver() {
@@ -69,8 +98,8 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         return newLight();
     }
 
-    public static IPBSolver newDefault() {
-        return org.sat4j.pb.SolverFactory.newResolutionGlucoseExpSimp();
+    public static IPBSolver newDefault() {    
+        return org.sat4j.pb.SolverFactory.newDefault();
     }
 
     public static IPBSolver newLight() {
