@@ -48,11 +48,8 @@ public class ConstraintRelaxingPseudoOptDecorator extends PBSolverDecorator
         implements IOptimizationProblem {
 
     private static final long serialVersionUID = 1L;
-    private int[] bestModel;
-    private boolean[] bestFullModel;
     private IConstr previousPBConstr;
     private IConstr addedConstr = null;
-    private int maxValue = 0;
     private Number objectiveValue;
     private boolean optimumFound = false;
 
@@ -75,11 +72,6 @@ public class ConstraintRelaxingPseudoOptDecorator extends PBSolverDecorator
             throws TimeoutException {
         boolean result = super.isSatisfiable(assumps, true);
         if (result) {
-            this.bestModel = super.model();
-            this.bestFullModel = new boolean[nVars()];
-            for (int i = 0; i < nVars(); i++) {
-                this.bestFullModel[i] = decorated().model(i + 1);
-            }
             calculateObjective();
         } else {
             if (this.previousPBConstr != null) {
@@ -106,29 +98,24 @@ public class ConstraintRelaxingPseudoOptDecorator extends PBSolverDecorator
         if (this.optimumFound) {
             return false;
         }
-        this.maxValue = getObjectiveFunction().minValue().intValue();
+        int maxValue = getObjectiveFunction().minValue().intValue();
         while (true) {
             if (this.addedConstr != null) {
                 this.decorated().removeConstr(this.addedConstr);
             }
             try {
-                forceObjectiveValueTo(this.maxValue++);
+                forceObjectiveValueTo(maxValue++);
             } catch (ContradictionException e) {
                 if (isVerbose()) {
                     System.out.println(decorated().getLogPrefix()
                             + "no solution for objective value "
-                            + (this.maxValue - 1));
+                            + (maxValue - 1));
                 }
                 continue;
             }
             isSatisfiable = super.isSatisfiable(assumps, true);
             if (isSatisfiable) {
                 this.optimumFound = true;
-                this.bestModel = super.model();
-                this.bestFullModel = new boolean[nVars()];
-                for (int i = 0; i < nVars(); i++) {
-                    this.bestFullModel[i] = decorated().model(i + 1);
-                }
                 if (getObjectiveFunction() != null) {
                     calculateObjective();
                 }
@@ -137,8 +124,7 @@ public class ConstraintRelaxingPseudoOptDecorator extends PBSolverDecorator
             }
             if (isVerbose()) {
                 System.out.println(decorated().getLogPrefix()
-                        + "no solution for objective value "
-                        + (this.maxValue - 1));
+                        + "no solution for objective value " + (maxValue - 1));
             }
         }
     }
@@ -191,4 +177,8 @@ public class ConstraintRelaxingPseudoOptDecorator extends PBSolverDecorator
                 + super.toString(prefix);
     }
 
+    public void setTimeoutForFindingBetterSolution(int seconds) {
+        throw new UnsupportedOperationException("Does not make sense here");
+    }
+
 }
\ No newline at end of file
