@@ -37,6 +37,7 @@ import org.sat4j.core.ReadOnlyVecInt;
 import org.sat4j.specs.ISolver;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.RandomAccessModel;
 
 /**
  * Abstraction for an Objective Function for Pseudo Boolean Optimization.
@@ -65,15 +66,22 @@ public class ObjectiveFunction implements Serializable {
         this.coeffs = new ReadOnlyVec<BigInteger>(coeffs);
     }
 
-    // calculate the degree of the objective function
-    public BigInteger calculateDegree(ISolver solver) {
+    /**
+     * Compute the degree of the objective function using a full model.
+     * 
+     * @param lazyModel
+     *            a solver that recently answered true to isSatisfiable()
+     * @return the value of the objective function for the last model found be
+     *         the solver.
+     */
+    public BigInteger calculateDegree(RandomAccessModel lazyModel) {
         BigInteger tempDegree = BigInteger.ZERO;
         for (int i = 0; i < this.vars.size(); i++) {
             BigInteger coeff = this.coeffs.get(i);
-            if (varInModel(this.vars.get(i), solver)) {
+            if (varInModel(this.vars.get(i), lazyModel)) {
                 tempDegree = tempDegree.add(coeff);
             } else if (coeff.signum() < 0
-                    && !varInModel(-this.vars.get(i), solver)) {
+                    && !varInModel(-this.vars.get(i), lazyModel)) {
                 // the variable does not appear in the model: it can be assigned
                 // either way
                 tempDegree = tempDegree.add(coeff);
@@ -82,10 +90,19 @@ public class ObjectiveFunction implements Serializable {
         return tempDegree;
     }
 
-    // calculate the degree of the objective function
+    /**
+     * Compute the degree of the objective function using a prime implicant. It
+     * is expected that the method IProblem.primeImplicant() has been called
+     * before calling that method.
+     * 
+     * @param solver
+     *            a solver which recently answered true to isSatisfiable and on
+     *            which the method primeImplicant() has been called.
+     * @return
+     * @see org.sat4j.specs.IProblem#primeImplicant()
+     */
     public BigInteger calculateDegreeImplicant(ISolver solver) {
         BigInteger tempDegree = BigInteger.ZERO;
-        solver.primeImplicant();
         for (int i = 0; i < this.vars.size(); i++) {
             BigInteger coeff = this.coeffs.get(i);
             if (solver.primeImplicant(this.vars.get(i))) {
@@ -100,11 +117,11 @@ public class ObjectiveFunction implements Serializable {
         return tempDegree;
     }
 
-    private boolean varInModel(int var, ISolver solver) {
+    private boolean varInModel(int var, RandomAccessModel lazyModel) {
         if (var > 0) {
-            return solver.model(var);
+            return lazyModel.model(var);
         }
-        return !solver.model(-var);
+        return !lazyModel.model(-var);
     }
 
     public IVec<BigInteger> getCoeffs() {
@@ -153,28 +170,20 @@ public class ObjectiveFunction implements Serializable {
         return tempDegree;
     }
 
-    public BigInteger calculateDegree(int[] model) {
-        BigInteger tempDegree = BigInteger.ZERO;
-
-        for (int i = 0; i < this.vars.size(); i++) {
-            BigInteger coeff = this.coeffs.get(i);
-            if (varInModel(this.vars.get(i), model)) {
-                tempDegree = tempDegree.add(coeff);
-            } else if (coeff.signum() < 0
-                    && !varInModel(-this.vars.get(i), model)) {
-                tempDegree = tempDegree.add(coeff);
-            }
-        }
-        return tempDegree;
+    @Override
+    public int hashCode() {
+        return this.coeffs.hashCode() / 3 + this.vars.hashCode() / 3
+                + this.correction.hashCode() / 3;
     }
 
-    private boolean varInModel(int var, int[] model) {
-        for (int element : model) {
-            if (var == element) {
-                return true;
-            }
+    @Override
+    public boolean equals(Object obj) {
+        if (obj instanceof ObjectiveFunction) {
+            ObjectiveFunction of = (ObjectiveFunction) obj;
+            return of.correction.equals(this.correction)
+                    && of.coeffs.equals(this.coeffs)
+                    && of.vars.equals(this.vars);
         }
         return false;
     }
-
 }
