@@ -41,8 +41,10 @@ import org.sat4j.minisat.orders.RSATPhaseSelectionStrategy;
 import org.sat4j.minisat.orders.UserFixedPhaseSelectionStrategy;
 import org.sat4j.minisat.orders.VarOrderHeap;
 import org.sat4j.minisat.restarts.ArminRestarts;
+import org.sat4j.minisat.restarts.Glucose21Restarts;
 import org.sat4j.minisat.restarts.LubyRestarts;
 import org.sat4j.minisat.restarts.MiniSATRestarts;
+import org.sat4j.minisat.restarts.NoRestarts;
 import org.sat4j.pb.constraints.AbstractPBDataStructureFactory;
 import org.sat4j.pb.constraints.CompetMinHTmixedClauseCardConstrDataStructureFactory;
 import org.sat4j.pb.constraints.CompetResolutionMinPBLongMixedWLClauseCardConstrDataStructure;
@@ -69,10 +71,7 @@ import org.sat4j.pb.core.PBSolverResCP;
 import org.sat4j.pb.core.PBSolverResolution;
 import org.sat4j.pb.core.PBSolverWithImpliedClause;
 import org.sat4j.pb.orders.VarOrderHeapObjective;
-import org.sat4j.pb.tools.ClausalConstraintsDecorator;
 import org.sat4j.pb.tools.ManyCorePB;
-import org.sat4j.specs.ISolver;
-import org.sat4j.tools.DimacsOutputSolver;
 
 /**
  * User friendly access to pre-constructed solvers.
@@ -80,7 +79,7 @@ import org.sat4j.tools.DimacsOutputSolver;
  * @author leberre
  * @since 2.0
  */
-public class SolverFactory extends ASolverFactory<IPBSolver> {
+public final class SolverFactory extends ASolverFactory<IPBSolver> {
 
     /**
      * 
@@ -193,7 +192,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         PBSolverCP solver = new PBSolverCP(learning,
                 new PBMaxClauseCardConstrDataStructure(),
                 new VarOrderHeapObjective());
-        learning.setSolver(solver);
         return solver;
     }
 
@@ -202,7 +200,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         PBSolverCP solver = new PBSolverCP(learning,
                 new PBMaxClauseCardConstrDataStructure(),
                 new VarOrderHeapObjective());
-        learning.setSolver(solver);
         return solver;
     }
 
@@ -211,7 +208,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         PBSolverCP solver = new PBSolverCP(learning,
                 new PBMaxClauseCardConstrDataStructure(),
                 new VarOrderHeapObjective(phase));
-        learning.setSolver(solver);
         return solver;
     }
 
@@ -232,7 +228,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         PBSolverCP solver = new PBSolverCP(learning,
                 new PBMaxClauseCardConstrDataStructure(),
                 new VarOrderHeapObjective(phase));
-        learning.setSolver(solver);
         return solver;
     }
 
@@ -280,7 +275,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         PBSolverCP solver = new PBSolverCP(learning,
                 new PBMaxClauseCardConstrDataStructure(),
                 new VarOrderHeapObjective());
-        learning.setSolver(solver);
         learning.setVarActivityListener(solver);
         return solver;
     }
@@ -613,7 +607,10 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
      * @return a solver for unsatisfiable benchmarks.
      */
     public static PBSolverResolution newUNSAT() {
-        return newResolutionGlucose();
+        PBSolverResolution solver = newResolutionGlucose();
+        solver.setRestartStrategy(new NoRestarts());
+        solver.setSimplifier(solver.SIMPLE_SIMPLIFICATION);
+        return solver;
     }
 
     /**
@@ -627,10 +624,26 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
     public static PBSolverResolution newResolutionGlucose() {
         PBSolverResolution solver = newCompetPBResLongWLMixedConstraintsObjectiveExpSimp();
         solver.setSimplifier(Solver.NO_SIMPLIFICATION);
+        solver.setRestartStrategy(new Glucose21Restarts());
         solver.setLearnedConstraintsDeletionStrategy(solver.glucose);
         return solver;
     }
 
+    /**
+     * Resolution based solver (i.e. classic SAT solver able to handle generic
+     * constraints. No specific inference mechanism). Uses glucose based memory
+     * management. The reason simplification is now disabled by default because
+     * it slows down a lot when long PB or cardinality constraints are used.
+     * Uses the dynamic restart strategy of Glucose21.
+     * 
+     * @return the best available resolution based solver of the library.
+     */
+    public static PBSolverResolution newResolutionGlucose21() {
+        PBSolverResolution solver = newResolutionGlucose();
+        solver.setRestartStrategy(new Glucose21Restarts());
+        return solver;
+    }
+
     /**
      * Resolution based solver (i.e. classic SAT solver able to handle generic
      * constraints. No specific inference mechanism). Uses glucose based memory
@@ -710,7 +723,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
      *      instance of ASolverFactory.
      */
     public static PBSolver newDefault() {
-        return newResolutionGlucose();
+        return newResolutionGlucose21();
     }
 
     /**
@@ -729,11 +742,30 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         return solver;
     }
 
+    /**
+     * Provides the best available PB solver of the library ready to solve
+     * satisfaction problems. If you need to solve optimization problems, please
+     * use {@link #newDefaultOptimizer()}
+     * 
+     * @return a solver ready to solve satisfaction problems.
+     */
     @Override
     public PBSolver defaultSolver() {
         return newDefault();
     }
 
+    /**
+     * Provides the best available PB solver of the library ready to solve
+     * optimization problems. If you only need to solve satisfaction problems,
+     * please use {@link #newDefault()} instead.
+     * 
+     * @return a solver ready to solve optimization problems.
+     * @since 2.3.3
+     */
+    public static IPBSolver newDefaultOptimizer() {
+        return new OptToPBSATAdapter(new PseudoOptDecorator(newDefault()));
+    }
+
     /**
      * Small footprint SAT solver.
      * 
@@ -750,10 +782,6 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         return newLight();
     }
 
-    public static ISolver newDimacsOutput() {
-        return new ClausalConstraintsDecorator(new DimacsOutputSolver());
-    }
-
     public static IPBSolver newEclipseP2() {
         MiniSATLearning<PBDataStructureFactory> learning = new MiniSATLearning<PBDataStructureFactory>();
         PBSolverResolution solver = new PBSolverResolution(learning,
@@ -764,6 +792,7 @@ public class SolverFactory extends ASolverFactory<IPBSolver> {
         learning.setVarActivityListener(solver);
         solver.setTimeoutOnConflicts(300);
         solver.setVerbose(false);
+        solver.setLearnedConstraintsDeletionStrategy(solver.memory_based);
         return new OptToPBSATAdapter(new PseudoOptDecorator(solver));
     }
 
