@@ -35,6 +35,7 @@ import java.math.BigInteger;
 import org.sat4j.core.Vec;
 import org.sat4j.core.VecInt;
 import org.sat4j.minisat.constraints.AbstractDataStructureFactory;
+import org.sat4j.minisat.constraints.card.AtLeast;
 import org.sat4j.minisat.constraints.cnf.Clauses;
 import org.sat4j.minisat.constraints.cnf.LearntBinaryClause;
 import org.sat4j.minisat.constraints.cnf.LearntHTClause;
@@ -193,48 +194,42 @@ public abstract class AbstractPBDataStructureFactory extends
         return createPseudoBooleanConstraint(literals, coefs, true, degree);
     }
 
-    // public Constr createPseudoBooleanConstraint(IVecInt literals,
-    // IVecInt coefs, boolean moreThan, BigInteger degree)
-    // throws ContradictionException;
-    //
-    // public Constr createAtMostPBConstraint(IVecInt literals, IVecInt coefs,
-    // boolean moreThan, BigInteger degree) throws ContradictionException {
-    // return createPseudoBooleanConstraint(literals, coefs, false, degree);
-    // }
-    //
-    // public Constr createAtLeastPBConstraint(IVecInt literals, IVecInt coefs,
-    // boolean moreThan, BigInteger degree) throws ContradictionException {
-    // return createPseudoBooleanConstraint(literals, coefs, true, degree);
-    // }
-    //
-    // public Constr createAtMostPBConstraint(IVecInt literals, long[] coefs,
-    // boolean moreThan, BigInteger degree) throws ContradictionException {
-    // return createPseudoBooleanConstraint(literals, coefs, false, degree);
-    // }
-    //
-    // public Constr createAtLeastPBConstraint(IVecInt literals, long[] coefs,
-    // boolean moreThan, BigInteger degree) throws ContradictionException {
-    // return createPseudoBooleanConstraint(literals, coefs, true, degree);
-    // }
-    //
-    // public Constr createPseudoBooleanConstraint(IVecInt literals, long[]
-    // coefs,
-    // boolean moreThan, BigInteger degree) throws ContradictionException;
-
     public Constr createUnregisteredPseudoBooleanConstraint(
             IDataStructurePB dspb) {
         return learntConstraintFactory(dspb);
     }
 
+    public Constr createUnregisteredAtLeastConstraint(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntAtLeastConstraintFactory(literals, coefs, degree);
+    }
+
+    public Constr createUnregisteredAtMostConstraint(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntAtMostConstraintFactory(literals, coefs, degree);
+    }
+
     protected abstract Constr constraintFactory(int[] literals,
             BigInteger[] coefs, BigInteger degree)
             throws ContradictionException;
 
     protected abstract Constr learntConstraintFactory(IDataStructurePB dspb);
 
+    protected abstract Constr learntAtLeastConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree);
+
+    protected abstract Constr learntAtMostConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree);
+
     @Override
     protected ILits createLits() {
         return new Lits();
     }
 
+    @Override
+    public Constr createUnregisteredCardinalityConstraint(IVecInt literals,
+            int degree) {
+        return new AtLeast(getVocabulary(), literals, degree);
+    }
+
 }
