@@ -36,11 +36,11 @@ import org.sat4j.core.VecInt;
 import org.sat4j.minisat.constraints.card.AtLeast;
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.pb.constraints.pb.IDataStructurePB;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.UnitPropagationListener;
 
 public class AtLeastCardConstructor implements ICardConstructor {
 
