@@ -33,9 +33,9 @@ import java.math.BigInteger;
 
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.pb.constraints.pb.IDataStructurePB;
 import org.sat4j.specs.ContradictionException;
+import org.sat4j.specs.UnitPropagationListener;
 
 public interface IPBConstructor {
 
