@@ -36,12 +36,12 @@ import org.sat4j.core.VecInt;
 import org.sat4j.minisat.constraints.card.MinWatchCard;
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
-import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.pb.constraints.pb.IDataStructurePB;
 import org.sat4j.pb.constraints.pb.MinWatchCardPB;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.UnitPropagationListener;
 
 public class MinCardPBConstructor implements ICardConstructor {
 
