@@ -33,9 +33,13 @@ import java.math.BigInteger;
 
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.pb.constraints.pb.IDataStructurePB;
+import org.sat4j.pb.constraints.pb.MapPb;
 import org.sat4j.pb.constraints.pb.MinWatchPb;
 import org.sat4j.pb.constraints.pb.PBConstr;
+import org.sat4j.pb.constraints.pb.Pseudos;
 import org.sat4j.specs.ContradictionException;
+import org.sat4j.specs.IVec;
+import org.sat4j.specs.IVecInt;
 
 /**
  * @author leberre To change the template for this generated type comment go to
@@ -72,4 +76,35 @@ public class PBMinDataStructure extends AbstractPBDataStructureFactory {
         return MinWatchPb.normalizedWatchPbNew(getVocabulary(), dspb);
     }
 
+    /*
+     * (non-Javadoc)
+     * 
+     * @seeorg.sat4j.minisat.constraints.AbstractPBDataStructureFactory#
+     * constraintFactory(org.sat4j.specs.VecInt, org.sat4j.specs.VecInt, int)
+     */
+    private Constr learntConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree, boolean moreThan) {
+        int[] lits = new int[literals.size()];
+        literals.copyTo(lits);
+        BigInteger[] bc = new BigInteger[coefs.size()];
+        coefs.copyTo(bc);
+        degree = Pseudos.niceCheckedParametersForCompetition(lits, bc,
+                moreThan, degree);
+
+        return MinWatchPb.normalizedWatchPbNew(getVocabulary(), new MapPb(
+                literals, coefs, degree));
+    }
+
+    @Override
+    protected Constr learntAtLeastConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntConstraintFactory(literals, coefs, degree, true);
+    }
+
+    @Override
+    protected Constr learntAtMostConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntConstraintFactory(literals, coefs, degree, false);
+    }
+
 }
