@@ -33,7 +33,6 @@ import java.math.BigInteger;
 
 public interface IWatchPb extends PBConstr {
 
-    public BigInteger slackConstraint(BigInteger[] theCoefs,
-            BigInteger theDegree);
+	BigInteger slackConstraint(BigInteger[] theCoefs, BigInteger theDegree);
 
 }
