@@ -42,9 +42,16 @@ import org.sat4j.specs.IVecInt;
  */
 public class InternalMapPBStructure {
 
-    IVecInt lits;
-    IVec<BigInteger> coefs;
-    IVecInt allLits;
+    private final IVecInt lits;
+    private final IVec<BigInteger> coefs;
+    private IVecInt allLits;
+
+    // temporarily : just for the case where an InternalMapPBStructure
+    // is used to embed in one object literals and coefs
+    InternalMapPBStructure(IVecInt lits, IVec<BigInteger> coefs) {
+        this.lits = lits;
+        this.coefs = coefs;
+    }
 
     InternalMapPBStructure(int size) {
         assert size > 0;
@@ -69,12 +76,15 @@ public class InternalMapPBStructure {
         }
     }
 
-    // coefs.get(lit)
     BigInteger get(int lit) {
         assert this.allLits.get(lit) != -1;
         return this.coefs.get(this.allLits.get(lit));
     }
 
+    int getFromAllLits(int lit) {
+        return this.allLits.get(lit);
+    }
+
     int getLit(int indLit) {
         assert indLit < this.lits.size();
         return this.lits.get(indLit);
@@ -85,7 +95,6 @@ public class InternalMapPBStructure {
         return this.coefs.get(indLit);
     }
 
-    // coefs.containsKey(nLitImplied)
     boolean containsKey(int lit) {
         return this.allLits.get(lit) != -1;
     }
@@ -94,7 +103,6 @@ public class InternalMapPBStructure {
         return this.lits.size();
     }
 
-    // coefs.put(lit, newValue)
     void put(int lit, BigInteger newValue) {
         int indLit = this.allLits.get(lit);
         if (indLit != -1) {
@@ -111,8 +119,6 @@ public class InternalMapPBStructure {
         this.coefs.set(indLit, newValue);
     }
 
-    // void removeCoef(Integer lit) {
-    // coefs.remove(lit);
     void remove(int lit) {
         int indLit = this.allLits.get(lit);
         if (indLit != -1) {
