@@ -1002,7 +1002,7 @@ public class DetailedCommandPanel extends JPanel implements SolverController,
                 } else {
                     this.problem = new PseudoOptDecorator(
                             (WeightedMaxSatDecorator) this.problem, false,
-                            !equivalenceMode);
+                            false);
                 }
 
                 this.problem = new OptToPBSATAdapter(
@@ -1689,6 +1689,9 @@ public class DetailedCommandPanel extends JPanel implements SolverController,
     public void learn(IConstr c) {
     }
 
+    public void learnUnit(int p) {        
+    }
+    
     public void delete(int[] clause) {
     }
 
